------------------------------------------------------------------------------
-- MakeMeGetMyMain - Alarms you when something happens to your character
------------------------------------------------------------------------------
-- Trigger_Loot.lua - Triggered if character loots special items
--
-- Author: Expelliarm5s / June 2022 / All Rights Reserved
--
-- Version 1.1.16
------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI

local addonName, addon = ...
local modle = addon:NewModule("Loot", "AceEvent-3.0", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
-- local private = {}
------------------------------------------------------------------------------

function modle:ModuleName()
	return modle.moduleName
end

function modle:ToggleMod()
	addon.db.global[modle.moduleName] = addon.db.global[modle.moduleName] or false
	addon.db.global[modle.moduleName] = not addon.db.global[modle.moduleName]
	if addon.db.global[modle.moduleName] then
		addon:Printf(L["Module %s enabled"], modle.moduleName)
	else
		addon:Printf(L["Module %s disabled"], modle.moduleName)
	end
end

function modle:EnableMod()
	addon.db.global[modle.moduleName] = true
	addon:Printf(L["Module %s enabled"], modle.moduleName)
end

function modle:DisableMod()
	addon.db.global[modle.moduleName] = false
	addon:Printf(L["Module %s disabled"], modle.moduleName)
end

function modle:Login()
	modle:RegisterEvent("LOOT_OPENED")
end

function modle:ModuleIcon()
	return "INTERFACE\\ICONS\\INV_Misc_Gift_01"
end

function modle:TriggerName()
	return L["Character got special item!"]
end

function modle:TriggerDesc()
	return L["Alarm fires on special item drop."]
end

function modle:GetItemID(val)
	if type(val) == "number" then
		return val
	end

	if type(val) == "string" then
		local id = val:match("item:([0-9]+)")
		if id and tonumber(id) then
			return tonumber(id)
		end
	end
end

function modle:GetOptions()
	local options = {
		type = "input",
		name = L["List of ItemIDs:"],
		desc = L["ItemIDs to trigger an alarm on drop, e.g. \"163573, 163574, 163575, 163576, 163131\" " ..
			"for BfA mounts or \"epic, 163573\" for item 163573 and any epics."],
		width = "full",
		get = function(info)
			return addon.db.global.LootItemIDs
		end,
		set = function(info, value)
			if value then
				addon.db.global.LootItemIDs = value
			end
		end,
	}
	return options
end

function modle:EscapedLink(link)
	local l = ""
	if type(link) == "string" and link:match("^\124(.+)\124h") then
		l = gsub(link, "\124", "\124\124")
	end
	return l
end

function modle:LOOT_OPENED(event)
	addon:DebugPrintf(modle.moduleName .. "~  %s", tostring(event))
	if event == "LOOT_OPENED" then
		if addon.isEnabled and addon.db.global[modle.moduleName] then
			for i = 1, GetNumLootItems() do
				local slotType = GetLootSlotType(i);
				if slotType == 1 then
					-- items
					local itemLink = GetLootSlotLink(i)
					local lootIcon, lootName, lootQuantity, lootCurrencyID, lootQuality, lootLocked, lootIsQuestItem, lootQuestID, lootIsActive = GetLootSlotInfo(i)
					local itemID = modle:GetItemID(itemLink)

					addon:DebugPrintf(modle.moduleName .. "~%s: link=%s / %s id=%s" .. " info 1=%s 2=%s 3=%s 4=%s 5=%s 6=%s 7=%s 8=%s 9=%s",
						tostring(i), tostring(itemLink), modle:EscapedLink(itemLink), tostring(itemID),
						tostring(lootIcon), tostring(lootName), tostring(lootQuantity), tostring(lootCurrencyID), tostring(lootQuality), tostring(lootLocked),
						tostring(lootIsQuestItem), tostring(lootQuestID), tostring(lootIsActive))

					if itemID and addon.db.global.LootItemIDs and type(addon.db.global.LootItemIDs) == "string" then
						local itemIDs = addon.db.global.LootItemIDs:lower() .. ","
						itemIDs = gsub(itemIDs, " ", "")

						-- addon:DebugPrintf(modle.moduleName .. "~itemIDs = '%s'", tostring(itemIDs))

						itemIDs:gsub("([0-9]+),",
							function(j)
								-- addon:DebugPrintf(modle.moduleName .. "~j = '%s'", tostring(j))

								if j and tonumber(j) then
									addon:DebugPrintf(modle.moduleName .. "~  looking for %s", tostring(j))
									if tonumber(itemID) == tonumber(j) then
										addon:DebugPrintf(modle.moduleName .. "~  found %s for ItemID %s", tostring(itemLink), tostring(itemID))
										addon:DebugPrintf(modle.moduleName .. "~  -> GUI:Fire(%s, %s)", modle.moduleName, tostring(lootIcon))
										addon:Printf(format(L["Module %s: %s (%s / %s)"], modle.moduleName, modle:TriggerName(), tostring(itemID), tostring(itemLink)))
										if addon.GUI.Fire then
											addon.GUI:Fire(modle.moduleName, lootIcon)
										end
									end
								end
							end)

						-- addon:DebugPrintf(modle.moduleName .. "~itemIDs = '%s'", tostring(itemIDs))

						itemIDs:gsub("([a-z]+),",
							function(j)
								-- addon:DebugPrintf(modle.moduleName .. "~j = '%s'", tostring(j))
								for key, quality in pairs(Enum.ItemQuality) do
									key = key:lower()
									if j == key then
										addon:DebugPrintf(modle.moduleName .. "~  looking for %s/%s", tostring(key), tostring(quality), tostring(itemID))
										if quality == lootQuality then
											addon:DebugPrintf(modle.moduleName .. "~  found %s for quality %s", tostring(itemLink), tostring(key))
											addon:DebugPrintf(modle.moduleName .. "~  -> GUI:Fire(%s, %s)", modle.moduleName, tostring(lootIcon))
											addon:Printf(format(L["Module %s: %s (%s / %s)"], modle.moduleName, modle:TriggerName(), tostring(itemID), tostring(itemLink)))
											if addon.GUI.Fire then
												addon.GUI:Fire(modle.moduleName, lootIcon)
											end
										end
									end
								end
							end)
					end
				end
			end
		end
	end
end

-- EOF